@@ -25,3 +25,7 @@ else
     
 fi
 
+echo -e "\e[1;31mFor further queries please follow below URL\e[0m"
+
+echo -e "\e[1;31mhttps://github.com/openvinotoolkit/openvino/tree/master/tools\e[0m"
+
